export { dbQuery, type QueryColumn, QueryColumnSchema, type QueryResult, QueryResultSchema, QueryResponseSchema, } from '@agentuity/core/db';
export { dbTables, generateCreateTableSQL, type TableColumn, TableColumnSchema, type TableSchema, TableSchemaSchema, TablesResponseSchema, } from '@agentuity/core/db';
export { dbLogs, type DbQueryLog, DbQueryLogSchema, type DbQueryLogs, DbLogsAPIResponseSchema, DbLogsRequestSchema, DbLogsResponseSchema, } from '@agentuity/core/db';
export { dbLogStats, type DbLogStatsResponse, type DbLogStatsSummary, type DbLogStatsCommandBreakdown, type DbLogStatsQueryPattern, type DbLogStatsTimeSeriesPoint, DbLogStatsAPIResponseSchema, DbLogStatsCommandBreakdownSchema, DbLogStatsQueryPatternSchema, DbLogStatsRequestSchema, DbLogStatsResponseSchema, DbLogStatsSummarySchema, DbLogStatsTimeSeriesPointSchema, } from '@agentuity/core/db';
export { DbInvalidArgumentError, DbResponseError } from '@agentuity/core/db';
import { type Logger } from '@agentuity/core';
import { z } from 'zod';
import { type QueryResult, type TableSchema, type DbQueryLogs, type DbLogStatsResponse } from '@agentuity/core/db';
export declare const DBClientOptionsSchema: z.ZodObject<{
    apiKey: z.ZodOptional<z.ZodString>;
    url: z.ZodOptional<z.ZodString>;
    database: z.ZodString;
    orgId: z.ZodString;
    region: z.ZodOptional<z.ZodString>;
    logger: z.ZodOptional<z.ZodCustom<Logger, Logger>>;
}, z.core.$strip>;
export type DBClientOptions = z.infer<typeof DBClientOptionsSchema>;
export declare class DBClient {
    #private;
    constructor(options: DBClientOptions);
    query(sql: string): Promise<QueryResult>;
    tables(): Promise<TableSchema[]>;
    logs(params?: {
        startDate?: string;
        endDate?: string;
        limit?: number;
    }): Promise<DbQueryLogs>;
    stats(params: {
        startDate: string;
        endDate: string;
    }): Promise<DbLogStatsResponse>;
}
//# sourceMappingURL=index.d.ts.map